@@ -11,8 +11,10 @@
 #include <ws2tcpip.h>
 
 extern "C" {
+#include <afsconfig.h>
 #include <afs/param.h>
 #include <afs/stds.h>
+#include <roken.h>
 }
 
 #include "TaAfsAdmSvrInternal.h"
@@ -651,7 +653,7 @@ void AfsAdmSvr_Action_StartRefresh (ASID idScope)
       {
       case itCELL:
          AfsAdmSvr_MarkRefreshThread (idScope);
-         // fall through
+         AFS_FALLTHROUGH;
 
       case itSERVER:
          ASACTION Action;
