@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -57,9 +57,9 @@ LONG procListbox = 0;
  *
  */
 
-BOOL CALLBACK CheckListProc (HWND hList, UINT msg, WPARAM wp, LPARAM lp);
+HRESULT CALLBACK CheckListProc (HWND hList, UINT msg, WPARAM wp, LPARAM lp);
 
-BOOL CALLBACK CheckList_DialogProc (HWND hDlg, UINT msg, WPARAM wp, LPARAM lp);
+HRESULT CALLBACK CheckList_DialogProc (HWND hDlg, UINT msg, WPARAM wp, LPARAM lp);
 
 void CheckList_OnDrawItem (HWND hList, int id, LPDRAWITEMSTRUCT lpds);
 void CheckList_OnDrawCheckbox (HWND hList, int id, LPDRAWITEMSTRUCT lpds);
@@ -134,8 +134,11 @@ BOOL RegisterCheckListClass (void)
       wc.hbrBackground = CreateSolidBrush (GetSysColor (COLOR_BTNFACE));
       wc.lpszClassName = WC_CHECKLIST;
 
-      if (RegisterClass (&wc))
-         fRegistered = TRUE;
+	  if (RegisterClass (&wc)) {
+	      fRegistered = TRUE;
+	  } else {
+	      OutputDebugString("CheckList class registration failed\n");
+	  }
       }
 
    return fRegistered;
@@ -155,7 +158,7 @@ BOOL IsCheckList (HWND hList)
 }
 
 
-BOOL CALLBACK CheckListProc (HWND hList, UINT msg, WPARAM wp, LPARAM lp)
+HRESULT CALLBACK CheckListProc (HWND hList, UINT msg, WPARAM wp, LPARAM lp)
 {
     HRESULT hResult;
 
@@ -218,15 +221,15 @@ BOOL CALLBACK CheckListProc (HWND hList, UINT msg, WPARAM wp, LPARAM lp)
       }
 
    if (procListbox)
-      hResult = CallWindowProc ((WNDPROC)LongToPtr(procListbox), hList, msg, wp, lp);
+      hResult = (BOOL)CallWindowProc ((WNDPROC)LongToPtr(procListbox), hList, msg, wp, lp);
    else
-      hResult = DefWindowProc (hList, msg, wp, lp);
+      hResult = (BOOL)DefWindowProc (hList, msg, wp, lp);
 
-    return (hResult?TRUE:FALSE);
+    return (hResult);
 }
 
 
-BOOL CALLBACK CheckList_DialogProc (HWND hDlg, UINT msg, WPARAM wp, LPARAM lp)
+HRESULT CALLBACK CheckList_DialogProc (HWND hDlg, UINT msg, WPARAM wp, LPARAM lp)
 {
    PVOID procOld = Subclass_FindNextHook (hDlg, CheckList_DialogProc);
 
@@ -263,7 +266,7 @@ BOOL CALLBACK CheckList_DialogProc (HWND hDlg, UINT msg, WPARAM wp, LPARAM lp)
             if (clrNew != clrLast)
                hbrStatic = CreateSolidBrush (clrLast = clrNew);
             SetBkColor ((HDC)wp, clrLast);
-            return (BOOL)hbrStatic;
+            return (BOOL)(INT_PTR)hbrStatic;
             }
          break;
       }
@@ -365,7 +368,7 @@ void CheckList_OnDrawCheckbox (HWND hList, int id, LPDRAWITEMSTRUCT lpds)
    // step 2e: draw the background field
    //
    BOOL fHit = CheckList_OnHitTest (hList, id);
-   BOOL fChecked = LB_GetCheck (hList, id);
+   BOOL fChecked = (BOOL)LB_GetCheck (hList, id);
 
    clrBack = GetSysColor (COLOR_WINDOW);
    if ( (lpds->itemState & ODS_DISABLED) ||
@@ -549,7 +552,7 @@ void CheckList_OnMouseMove (HWND hList)
 {
    if (GetCapture() == hList)
       {
-      int ii = LB_GetHit (hList);
+      int ii = (int)LB_GetHit (hList);
       if (ii != -1)
          {
          CheckList_RedrawCheck (hList, ii);
@@ -566,7 +569,7 @@ void CheckList_OnButtonDown (HWND hList)
       POINT pt = { LOWORD(dw), HIWORD(dw) };
       ScreenToClient (hList, &pt);
 
-      int ii = SendMessage (hList, LB_ITEMFROMPOINT, 0, MAKELPARAM(pt.x,pt.y));
+      int ii = (int)SendMessage (hList, LB_ITEMFROMPOINT, 0, MAKELPARAM(pt.x,pt.y));
       if (HIWORD(ii) == 0)
          {
          BOOL fHit = CheckList_OnHitTest (hList, ii);
@@ -588,7 +591,7 @@ void CheckList_OnButtonUp (HWND hList)
       {
       ReleaseCapture();
 
-      int ii = LB_GetHit (hList);
+      int ii = (int)LB_GetHit (hList);
       if (ii != -1)
          {
          LB_SetHit (hList, -1);
@@ -599,7 +602,7 @@ void CheckList_OnButtonUp (HWND hList)
             CheckList_RedrawCheck (hList, ii);
          else
             {
-            BOOL fChecked = LB_GetCheck (hList, ii);
+            BOOL fChecked = (BOOL)LB_GetCheck (hList, ii);
             CheckList_OnSetCheck_Selected (hList, !fChecked);
             }
          }
@@ -615,10 +618,10 @@ void CheckList_OnDoubleClick (HWND hList)
       POINT pt = { LOWORD(dw), HIWORD(dw) };
       ScreenToClient (hList, &pt);
 
-      int ii = SendMessage (hList, LB_ITEMFROMPOINT, 0, MAKELPARAM(pt.x,pt.y));
+      int ii = (int)SendMessage (hList, LB_ITEMFROMPOINT, 0, MAKELPARAM(pt.x,pt.y));
       if (HIWORD(ii) == 0)
          {
-         BOOL fChecked = LB_GetCheck (hList, ii);
+         BOOL fChecked = (BOOL)LB_GetCheck (hList, ii);
 
          CheckList_OnSetCheck_Selected (hList, !fChecked);
          }
@@ -648,7 +651,7 @@ void CheckList_OnSetCheck_Selected (HWND hList, BOOL fCheck)
       }
    else // single-sel listbox
       {
-      int ii = SendMessage (hList, LB_GETCURSEL, 0, 0);
+      int ii = (int)SendMessage (hList, LB_GETCURSEL, 0, 0);
       if (ii != LB_ERR)
          {
          LB_SetCheck (hList, ii, fCheck);
