@@ -1,10 +1,14 @@
 /*
  * Copyright 2005,2006 Secure Endpoints Inc.
  * All Rights Reserved.
- * 
- * This software has been released under the terms of the MIT License.  
+ *
+ * This software has been released under the terms of the MIT License.
  */
 
+#include <afsconfig.h>
+#include <afs/param.h>
+#include <roken.h>
+
 #include <windows.h>
 #include <afskfw.h>
 
