@@ -252,7 +252,8 @@ void * cm_BkgDaemon(void * vparm)
                 cm_daemons[daemonID].retryCount++;
                 osi_QAddT((osi_queue_t **) &cm_daemons[daemonID].head, (osi_queue_t **)&cm_daemons[daemonID].tail, &rp->q);
                 break;
-            } /* otherwise fall through */
+            }
+            AFS_FALLTHROUGH;
         case 0:  /* success */
         default: /* other error */
             if (code == 0) {
@@ -645,7 +646,7 @@ void * cm_Daemon(void *vparm)
 
         if (configureFirewall) {
 	    /* Open Microsoft Firewall to allow in port 7001 */
-	    switch (icf_CheckAndAddAFSPorts(AFS_PORTSET_CLIENT)) {
+	    switch (icf_CheckAndAddAFSPorts(cm_callbackport)) {
 	    case 0:
 		afsi_log("Windows Firewall Configuration succeeded");
 		configureFirewall = 0;
@@ -881,17 +882,6 @@ void cm_DaemonShutdown(void)
 
     if (cm_LockDaemon_ShutdownEvent)
         code = thrd_WaitForSingleObject_Event(cm_LockDaemon_ShutdownEvent, INFINITE);
-
-#if 0
-    /*
-     * Do not waste precious time waiting for the ipaddr daemon to shutdown.
-     * When it does it means we have lost our network connection and we need
-     * it during cache shutdown in order to notify the file servers that this
-     * client is giving up all callbacks.
-     */
-    if (cm_IPAddrDaemon_ShutdownEvent)
-        code = thrd_WaitForSingleObject_Event(cm_IPAddrDaemon_ShutdownEvent, INFINITE);
-#endif
 }
 
 void cm_InitDaemon(int nDaemons)
