@@ -144,6 +144,7 @@ typedef struct cm_scache {
                                          * storing data */
 
     /* symlink and mount point info */
+    afs_uint64   mpDataVersion;         /* data version represented by mountPointStringp */
     char mountPointStringp[MOUNTPOINTLEN];	/* the string stored in a mount point;
                                                  * first char is type, then vol name.
                                          * If this is a normal symlink, we store
@@ -262,9 +263,7 @@ typedef struct cm_scache {
 #define CM_SCACHETYPE_INVALID           99      /* an invalid link */
 
 /* flag bits */
-#define CM_SCACHEFLAG_STATD             0x01    /* status info is valid */
 #define CM_SCACHEFLAG_DELETED           0x02    /* file has been deleted */
-#define CM_SCACHEFLAG_CALLBACK          0x04    /* have a valid callback */
 #define CM_SCACHEFLAG_STORING           0x08    /* status being stored back */
 #define CM_SCACHEFLAG_FETCHING		0x10	/* status being fetched */
 #define CM_SCACHEFLAG_SIZESTORING	0x20	/* status being stored that
@@ -345,6 +344,8 @@ typedef struct cm_scache {
 #define CM_MERGEFLAG_STOREDATA		2	/* Merge due to storedata op */
 #define CM_MERGEFLAG_DIROP              4       /* Merge due to directory op */
 #define CM_MERGEFLAG_FETCHDATA          8       /* Merge due to fetchdata op */
+#define CM_MERGEFLAG_BULKSTAT        0x10       /* Merge due to bulkstat op */
+#define CM_MERGEFLAG_CACHE_BYPASS    0x20       /* Data not stored into cache */
 
 /* hash define.  Must not include the cell, since the callback revocation code
  * doesn't necessarily know the cell in the case of a multihomed server
@@ -392,7 +393,9 @@ extern long cm_SyncOp(cm_scache_t *, struct cm_buf *, struct cm_user *,
 
 extern void cm_SyncOpDone(cm_scache_t *, struct cm_buf *, afs_uint32);
 
-extern void cm_MergeStatus(cm_scache_t * dscp, cm_scache_t * scp,
+extern long cm_IsStatusValid(AFSFetchStatus *statusp);
+
+extern long cm_MergeStatus(cm_scache_t * dscp, cm_scache_t * scp,
 			   struct AFSFetchStatus * statusp,
 			   struct AFSVolSync * volsyncp,
 			   struct cm_user *userp,
