@@ -213,12 +213,9 @@ long cm_MapRPCError(long error, cm_req_t *reqp)
 
     if (error == RX_CALL_DEAD ||
         error == RX_CALL_TIMEOUT ||
-        error == RX_CALL_BUSY ||
         error == RX_MSGSIZE ||
         error == VNOSERVICE)
 	error = CM_ERROR_TIMEDOUT;
-    else if (error == RX_CALL_IDLE)
-        error = EIO;
     else if (error == RX_INVALID_OPERATION)
         error = CM_ERROR_INVAL_NET_RESP;
     else if (error < 0)
@@ -283,8 +280,6 @@ long cm_MapRPCErrorRmdir(long error, cm_req_t *reqp)
 
     if (error == RX_CALL_DEAD ||
         error == RX_CALL_TIMEOUT ||
-        error == RX_CALL_BUSY ||
-        error == RX_CALL_IDLE ||
         error == RX_MSGSIZE ||
         error == VNOSERVICE)
 	error = CM_ERROR_TIMEDOUT;
@@ -337,8 +332,6 @@ long cm_MapVLRPCError(long error, cm_req_t *reqp)
 
     if (error == RX_CALL_DEAD ||
         error == RX_CALL_TIMEOUT ||
-        error == RX_CALL_BUSY ||
-        error == RX_CALL_IDLE ||
         error == RX_MSGSIZE ||
         error == VNOSERVICE)
 	error = CM_ERROR_TIMEDOUT;
@@ -775,7 +768,7 @@ int cm_MatchMask(clientchar_t *namep, clientchar_t *maskp, int flags)
             break;
         case '.':
             dot++;
-            /* fallthrough */
+            AFS_FALLTHROUGH;
         default:
             if ( star ) {
                 newmask[j++] = '*';
