@@ -55,13 +55,13 @@ unsigned long NetrWkstaGetInfo(
      */
     switch (Level) {
     case 102:
-        WkstaInfo->WkstaInfo102 = calloc(1, sizeof(WKSTA_INFO_102));
+        WkstaInfo->WkstaInfo102 = MIDL_user_allocate(sizeof(WKSTA_INFO_102));
         break;
     case 101:
-        WkstaInfo->WkstaInfo101 = calloc(1, sizeof(WKSTA_INFO_101));
+        WkstaInfo->WkstaInfo101 = MIDL_user_allocate(sizeof(WKSTA_INFO_101));
         break;
     case 100:
-        WkstaInfo->WkstaInfo100 = calloc(1, sizeof(WKSTA_INFO_100));
+        WkstaInfo->WkstaInfo100 = MIDL_user_allocate(sizeof(WKSTA_INFO_100));
         break;
     }
 
@@ -82,7 +82,7 @@ unsigned long NetrWkstaGetInfo(
         WkstaInfo->WkstaInfo101->wki101_lanroot = NULL;
     case  100:
         WkstaInfo->WkstaInfo100->wki100_computername = _wcsupr(wcsdup(s));
-        WkstaInfo->WkstaInfo100->wki100_langroup = _wcsdup(L"AFS");
+        WkstaInfo->WkstaInfo100->wki100_langroup = wcsdup(L"AFS");
         WkstaInfo->WkstaInfo100->wki100_platform_id = PLATFORM_ID_AFS;
         WkstaInfo->WkstaInfo100->wki100_ver_major = AFSPRODUCT_VERSION_MAJOR;
         WkstaInfo->WkstaInfo100->wki100_ver_minor = AFSPRODUCT_VERSION_MINOR;
