@@ -435,9 +435,11 @@ AFSCheckIoctlPermissions( IN ULONG ControlCode)
             return STATUS_SUCCESS;
 
         case IOCTL_AFS_CONFIGURE_DEBUG_TRACE:
+	case IOCTL_AFS_GET_DEBUG_TRACE:
         case IOCTL_AFS_GET_TRACE_BUFFER:
         case IOCTL_AFS_FORCE_CRASH:
 
+
             //
             // Any admin can call these
             //
@@ -527,7 +529,16 @@ AFSCheckIoctlPermissions( IN ULONG ControlCode)
 
                 return STATUS_ACCESS_DENIED;
             }
-            return STATUS_SUCCESS;
+	    return STATUS_SUCCESS;
+
+	case IOCTL_AFS_SET_REPARSE_POLICY:
+	case IOCTL_AFS_GET_REPARSE_POLICY:
+
+	    //
+	    // Anyone can call this
+	    //
+
+	    return STATUS_SUCCESS;
 
         default:
 
@@ -692,6 +703,31 @@ AFSProcessControlRequest( IN PIRP Irp)
                 break;
             }
 
+	    case IOCTL_AFS_GET_DEBUG_TRACE:
+	    {
+
+		AFSTraceConfigCB *pTraceInfo = (AFSTraceConfigCB *)Irp->AssociatedIrp.SystemBuffer;
+
+		if( pTraceInfo == NULL ||
+		    pIrpSp->Parameters.DeviceIoControl.OutputBufferLength < sizeof( AFSTraceConfigCB))
+		{
+
+		    ntStatus = STATUS_INVALID_PARAMETER;
+
+		    break;
+		}
+
+		ntStatus = AFSGetTraceConfig( pTraceInfo);
+
+		if ( NT_SUCCESS( ntStatus))
+		{
+
+		    Irp->IoStatus.Information = sizeof( AFSTraceConfigCB);
+		}
+
+		break;
+	    }
+
             case IOCTL_AFS_GET_TRACE_BUFFER:
             {
 
@@ -905,8 +941,48 @@ AFSProcessControlRequest( IN PIRP Irp)
                 break;
             }
 
-            default:
-            {
+	    case IOCTL_AFS_SET_REPARSE_POLICY:
+	    {
+
+		AFSSetReparsePointPolicyCB *pPolicy = (AFSSetReparsePointPolicyCB *)Irp->AssociatedIrp.SystemBuffer;
+
+		if( pPolicy == NULL ||
+		    pIrpSp->Parameters.DeviceIoControl.InputBufferLength < sizeof( AFSSetReparsePointPolicyCB))
+		{
+		    ntStatus = STATUS_INVALID_PARAMETER;
+		    break;
+		}
+
+		ntStatus = AFSSetReparsePointPolicy( pPolicy);
+
+		break;
+	    }
+
+	    case IOCTL_AFS_GET_REPARSE_POLICY:
+	    {
+
+		AFSGetReparsePointPolicyCB *pPolicy = (AFSGetReparsePointPolicyCB *)Irp->AssociatedIrp.SystemBuffer;
+
+		if( pPolicy == NULL ||
+		    pIrpSp->Parameters.DeviceIoControl.OutputBufferLength < sizeof( AFSGetReparsePointPolicyCB))
+		{
+		    ntStatus = STATUS_INVALID_PARAMETER;
+		    break;
+		}
+
+		ntStatus = AFSGetReparsePointPolicy( pPolicy);
+
+		if ( NT_SUCCESS( ntStatus))
+		{
+
+		    Irp->IoStatus.Information = sizeof( AFSGetReparsePointPolicyCB);
+		}
+
+		break;
+	    }
+
+	    default:
+	    {
 
                 //
                 // Check the state of the library
