@@ -38,6 +38,8 @@
 
 #include "AFSCommon.h"
 
+static HANDLE AFSServicePid = NULL;
+
 void
 AFSProcessNotify( IN HANDLE  ParentId,
                   IN HANDLE  ProcessId,
@@ -71,6 +73,7 @@ AFSProcessNotifyEx( IN OUT PEPROCESS Process,
                     IN     HANDLE ProcessId,
                     IN OUT PPS_CREATE_NOTIFY_INFO CreateInfo)
 {
+    UNREFERENCED_PARAMETER(Process);
 
     if ( CreateInfo)
     {
@@ -94,28 +97,27 @@ AFSProcessCreate( IN HANDLE ParentId,
                   IN HANDLE CreatingProcessId,
                   IN HANDLE CreatingThreadId)
 {
-    NTSTATUS ntStatus = STATUS_SUCCESS;
     AFSDeviceExt *pDeviceExt = (AFSDeviceExt *)AFSDeviceObject->DeviceExtension;
     AFSProcessCB *pProcessCB = NULL;
 
     __Enter
     {
 
-        AFSDbgLogMsg( AFS_SUBSYSTEM_LOCK_PROCESSING,
+        AFSDbgTrace(( AFS_SUBSYSTEM_LOCK_PROCESSING,
                       AFS_TRACE_LEVEL_VERBOSE,
-                      "AFSProcessCreate Acquiring Control ProcessTree.TreeLock lock %08lX EXCL %08lX\n",
+                      "AFSProcessCreate Acquiring Control ProcessTree.TreeLock lock %p EXCL %08lX\n",
                       pDeviceExt->Specific.Control.ProcessTree.TreeLock,
-                      PsGetCurrentThread());
+                      PsGetCurrentThread()));
 
         AFSAcquireExcl( pDeviceExt->Specific.Control.ProcessTree.TreeLock,
                         TRUE);
 
-        AFSDbgLogMsg( AFS_SUBSYSTEM_PROCESS_PROCESSING,
+        AFSDbgTrace(( AFS_SUBSYSTEM_PROCESS_PROCESSING,
                       AFS_TRACE_LEVEL_VERBOSE,
                       "AFSProcessCreate Parent %08lX Process %08lX %08lX\n",
                       ParentId,
                       ProcessId,
-                      PsGetCurrentThread());
+                      PsGetCurrentThread()));
 
         pProcessCB = AFSInitializeProcessCB( (ULONGLONG)ParentId,
                                              (ULONGLONG)ProcessId);
@@ -137,12 +139,12 @@ AFSProcessCreate( IN HANDLE ParentId,
         else
         {
 
-            AFSDbgLogMsg( AFS_SUBSYSTEM_PROCESS_PROCESSING,
+            AFSDbgTrace(( AFS_SUBSYSTEM_PROCESS_PROCESSING,
                           AFS_TRACE_LEVEL_ERROR,
                           "AFSProcessCreate Initialization failure for Parent %08lX Process %08lX %08lX\n",
                           ParentId,
                           ProcessId,
-                          PsGetCurrentThread());
+                          PsGetCurrentThread()));
         }
 
         AFSReleaseResource( pDeviceExt->Specific.Control.ProcessTree.TreeLock);
@@ -157,18 +159,18 @@ AFSProcessDestroy( IN HANDLE ProcessId)
 
     NTSTATUS ntStatus = STATUS_SUCCESS;
     AFSDeviceExt *pDeviceExt = (AFSDeviceExt *)AFSDeviceObject->DeviceExtension;
-    AFSProcessCB *pProcessCB = NULL, *pParentProcessCB = NULL;
+    AFSProcessCB *pProcessCB = NULL;
     AFSProcessAuthGroupCB *pProcessAuthGroup = NULL, *pLastAuthGroup = NULL;
     AFSThreadCB *pThreadCB = NULL, *pNextThreadCB = NULL;
 
     __Enter
     {
 
-        AFSDbgLogMsg( AFS_SUBSYSTEM_LOCK_PROCESSING,
+        AFSDbgTrace(( AFS_SUBSYSTEM_LOCK_PROCESSING,
                       AFS_TRACE_LEVEL_VERBOSE,
-                      "AFSProcessDestroy Acquiring Control ProcessTree.TreeLock lock %08lX EXCL %08lX\n",
+                      "AFSProcessDestroy Acquiring Control ProcessTree.TreeLock lock %p EXCL %08lX\n",
                       pDeviceExt->Specific.Control.ProcessTree.TreeLock,
-                      PsGetCurrentThreadId());
+                      PsGetCurrentThreadId()));
 
         AFSAcquireExcl( pDeviceExt->Specific.Control.ProcessTree.TreeLock,
                         TRUE);
@@ -176,11 +178,11 @@ AFSProcessDestroy( IN HANDLE ProcessId)
         // It's a remove so pull the entry
         //
 
-        AFSDbgLogMsg( AFS_SUBSYSTEM_PROCESS_PROCESSING,
+        AFSDbgTrace(( AFS_SUBSYSTEM_PROCESS_PROCESSING,
                       AFS_TRACE_LEVEL_VERBOSE,
                       "AFSProcessDestroy Process %08lX %08lX\n",
                       ProcessId,
-                      PsGetCurrentThread());
+                      PsGetCurrentThread()));
 
         ntStatus = AFSLocateHashEntry( pDeviceExt->Specific.Control.ProcessTree.TreeHead,
                                        (ULONGLONG)ProcessId,
@@ -223,12 +225,12 @@ AFSProcessDestroy( IN HANDLE ProcessId)
         }
         else
         {
-            AFSDbgLogMsg( AFS_SUBSYSTEM_PROCESS_PROCESSING,
+            AFSDbgTrace(( AFS_SUBSYSTEM_PROCESS_PROCESSING,
                           AFS_TRACE_LEVEL_WARNING,
                           "AFSProcessDestroy Process %08lX not found in ProcessTree Status %08lX %08lX\n",
                           ProcessId,
                           ntStatus,
-                          PsGetCurrentThread());
+                          PsGetCurrentThread()));
         }
 
         AFSReleaseResource( pDeviceExt->Specific.Control.ProcessTree.TreeLock);
@@ -272,21 +274,21 @@ AFSValidateProcessEntry( IN HANDLE  ProcessId,
         if ( !bProcessTreeLocked)
         {
 
-            AFSDbgLogMsg( AFS_SUBSYSTEM_LOCK_PROCESSING,
+            AFSDbgTrace(( AFS_SUBSYSTEM_LOCK_PROCESSING,
                           AFS_TRACE_LEVEL_VERBOSE,
-                          "AFSValidateProcessEntry Acquiring Control ProcessTree.TreeLock lock %08lX SHARED %08lX\n",
+                          "AFSValidateProcessEntry Acquiring Control ProcessTree.TreeLock lock %p SHARED %08lX\n",
                           pDeviceExt->Specific.Control.ProcessTree.TreeLock,
-                          PsGetCurrentThread());
+                          PsGetCurrentThread()));
 
             AFSAcquireShared( pDeviceExt->Specific.Control.ProcessTree.TreeLock,
                               TRUE);
         }
 
-        AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+        AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                       AFS_TRACE_LEVEL_VERBOSE,
                       "%s Entry for ProcessID %I64X\n",
                       __FUNCTION__,
-                      ullProcessID);
+                      ullProcessID));
 
         ntStatus = AFSLocateHashEntry( pDeviceExt->Specific.Control.ProcessTree.TreeHead,
                                        ullProcessID,
@@ -323,11 +325,11 @@ AFSValidateProcessEntry( IN HANDLE  ProcessId,
                 pProcessCB == NULL)
             {
 
-                AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+                AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                               AFS_TRACE_LEVEL_ERROR,
                               "%s Failed to locate process entry for ProcessID %I64X\n",
                               __FUNCTION__,
-                              ullProcessID);
+                              ullProcessID));
 
                 try_return( ntStatus = STATUS_UNSUCCESSFUL);
             }
@@ -346,11 +348,11 @@ AFSValidateProcessEntry( IN HANDLE  ProcessId,
         if( pProcessCB->ParentProcessId != 0)
         {
 
-            AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+            AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                           AFS_TRACE_LEVEL_VERBOSE,
                           "%s Locating process entry for Parent ProcessID %I64X\n",
                           __FUNCTION__,
-                          pProcessCB->ParentProcessId);
+                          pProcessCB->ParentProcessId));
 
             ntStatus = AFSLocateHashEntry( pDeviceExt->Specific.Control.ProcessTree.TreeHead,
                                            (ULONGLONG)pProcessCB->ParentProcessId,
@@ -362,21 +364,21 @@ AFSValidateProcessEntry( IN HANDLE  ProcessId,
                 AFSAcquireExcl( &pParentProcessCB->Lock,
                                 TRUE);
 
-                AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+                AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                               AFS_TRACE_LEVEL_VERBOSE,
                               "%s Located process entry for Parent ProcessID %I64X\n",
                               __FUNCTION__,
-                              pProcessCB->ParentProcessId);
+                              pProcessCB->ParentProcessId));
             }
         }
         else
         {
 
-            AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+            AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                           AFS_TRACE_LEVEL_VERBOSE,
                           "%s No parent ID for ProcessID %I64X\n",
                           __FUNCTION__,
-                          ullProcessID);
+                          ullProcessID));
         }
 
         AFSAcquireExcl( &pProcessCB->Lock,
@@ -409,11 +411,11 @@ AFSValidateProcessEntry( IN HANDLE  ProcessId,
         if( !NT_SUCCESS( ntStatus))
         {
 
-            AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+            AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                           AFS_TRACE_LEVEL_ERROR,
                           "%s Failed to locate callers SID for ProcessID %I64X\n",
                           __FUNCTION__,
-                          ullProcessID);
+                          ullProcessID));
 
             try_return( ntStatus);
         }
@@ -423,22 +425,22 @@ AFSValidateProcessEntry( IN HANDLE  ProcessId,
         if( ulSessionId == (ULONG)-1)
         {
 
-            AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+            AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                           AFS_TRACE_LEVEL_ERROR,
                           "%s Failed to retrieve session ID for ProcessID %I64X\n",
                           __FUNCTION__,
-                          ullProcessID);
+                          ullProcessID));
 
             try_return( ntStatus = STATUS_INSUFFICIENT_RESOURCES);
         }
 
-        AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+        AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                       AFS_TRACE_LEVEL_VERBOSE,
                       "%s Retrieved callers SID %wZ for ProcessID %I64X Session %08lX\n",
                       __FUNCTION__,
                       &uniSIDString,
                       ullProcessID,
-                      ulSessionId);
+                      ulSessionId));
 
         //
         // If there is an Auth Group for the current process,
@@ -458,14 +460,14 @@ AFSValidateProcessEntry( IN HANDLE  ProcessId,
                 RtlStringFromGUID( *pAuthGroup,
                                    &uniGUID);
 
-                AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+                AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                               AFS_TRACE_LEVEL_VERBOSE,
                               "%s Located valid AuthGroup GUID %wZ for SID %wZ ProcessID %I64X Session %08lX\n",
                               __FUNCTION__,
                               &uniGUID,
                               &uniSIDString,
                               ullProcessID,
-                              ulSessionId);
+                              ulSessionId));
 
                 if( uniGUID.Buffer != NULL)
                 {
@@ -510,14 +512,14 @@ AFSValidateProcessEntry( IN HANDLE  ProcessId,
                     RtlStringFromGUID( *(pProcessCB->ActiveAuthGroup),
                                        &uniGUID);
 
-                    AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+                    AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                                   AFS_TRACE_LEVEL_VERBOSE,
                                   "%s PID %I64X Session %08lX inherited Active AuthGroup %wZ from thread %I64X\n",
                                   __FUNCTION__,
                                   ullProcessID,
                                   ulSessionId,
                                   &uniGUID,
-                                  pParentThreadCB->ThreadId);
+                                  pParentThreadCB->ThreadId));
 
                     if( uniGUID.Buffer != NULL)
                     {
@@ -539,14 +541,14 @@ AFSValidateProcessEntry( IN HANDLE  ProcessId,
                     RtlStringFromGUID( *(pProcessCB->ActiveAuthGroup),
                                        &uniGUID);
 
-                    AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+                    AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                                   AFS_TRACE_LEVEL_VERBOSE,
                                   "%s PID %I64X Session %08lX inherited Active AuthGroup %wZ from parent PID %I64X\n",
                                   __FUNCTION__,
                                   ullProcessID,
                                   ulSessionId,
                                   &uniGUID,
-                                  pParentProcessCB->TreeEntry.HashIndex);
+                                  pParentProcessCB->TreeEntry.HashIndex));
 
                     if( uniGUID.Buffer != NULL)
                     {
@@ -568,14 +570,14 @@ AFSValidateProcessEntry( IN HANDLE  ProcessId,
                     RtlStringFromGUID( *(pProcessCB->ActiveAuthGroup),
                                        &uniGUID);
 
-                    AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+                    AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                                   AFS_TRACE_LEVEL_VERBOSE,
                                   "%s Returning(1) Active AuthGroup %wZ for SID %wZ PID %I64X Session %08lX\n",
                                   __FUNCTION__,
                                   &uniGUID,
                                   &uniSIDString,
                                   ullProcessID,
-                                  ulSessionId);
+                                  ulSessionId));
 
                     if( uniGUID.Buffer != NULL)
                     {
@@ -599,14 +601,14 @@ AFSValidateProcessEntry( IN HANDLE  ProcessId,
         if( !NT_SUCCESS( ntStatus))
         {
 
-            AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+            AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                           AFS_TRACE_LEVEL_ERROR,
                           "%s Failed to hash SID %wZ for PID %I64X Session %08lX Status %08lX\n",
                           __FUNCTION__,
                           &uniSIDString,
                           ullProcessID,
                           ulSessionId,
-                          ntStatus);
+                          ntStatus));
 
             try_return( ntStatus);
         }
@@ -661,14 +663,14 @@ AFSValidateProcessEntry( IN HANDLE  ProcessId,
                 RtlStringFromGUID( pSIDEntryCB->AuthGroup,
                                    &uniGUID);
 
-                AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+                AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                               AFS_TRACE_LEVEL_VERBOSE,
                               "%s  SID %wZ PID %I64X Session %08lX generated NEW AG %wZ\n",
                               __FUNCTION__,
                               &uniSIDString,
                               ullProcessID,
                               ulSessionId,
-                              &uniGUID);
+                              &uniGUID));
 
                 if( uniGUID.Buffer != NULL)
                 {
@@ -703,14 +705,14 @@ AFSValidateProcessEntry( IN HANDLE  ProcessId,
         RtlStringFromGUID( pSIDEntryCB->AuthGroup,
                            &uniGUID);
 
-        AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+        AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                       AFS_TRACE_LEVEL_VERBOSE,
                       "%s SID %wZ PID %I64X Session %08lX assigned AG %wZ\n",
                       __FUNCTION__,
                       &uniSIDString,
                       ullProcessID,
                       ulSessionId,
-                      &uniGUID);
+                      &uniGUID));
 
         if( uniGUID.Buffer != NULL)
         {
@@ -726,12 +728,12 @@ AFSValidateProcessEntry( IN HANDLE  ProcessId,
         {
             SetFlag( pProcessCB->Flags, AFS_PROCESS_LOCAL_SYSTEM_AUTH);
 
-            AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+            AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                           AFS_TRACE_LEVEL_VERBOSE,
                           "%s Setting PID %I64X Session %08lX with LOCAL SYSTEM AUTHORITY\n",
                           __FUNCTION__,
                           ullProcessID,
-                          ulSessionId);
+                          ulSessionId));
         }
 
         //
@@ -745,14 +747,14 @@ AFSValidateProcessEntry( IN HANDLE  ProcessId,
         RtlStringFromGUID( *(pProcessCB->ActiveAuthGroup),
                            &uniGUID);
 
-        AFSDbgLogMsg( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
+        AFSDbgTrace(( AFS_SUBSYSTEM_AUTHGROUP_PROCESSING,
                       AFS_TRACE_LEVEL_VERBOSE,
                       "%s Returning(2) Active AuthGroup %wZ for SID %wZ PID %I64X Session %08lX\n",
                       __FUNCTION__,
                       &uniGUID,
                       &uniSIDString,
                       ullProcessID,
-                      ulSessionId);
+                      ulSessionId));
 
         if( uniGUID.Buffer != NULL)
         {
@@ -815,11 +817,11 @@ AFSIs64BitProcess( IN ULONGLONG ProcessId)
     __Enter
     {
 
-        AFSDbgLogMsg( AFS_SUBSYSTEM_LOCK_PROCESSING,
+        AFSDbgTrace(( AFS_SUBSYSTEM_LOCK_PROCESSING,
                       AFS_TRACE_LEVEL_VERBOSE,
-                      "AFSIs64BitProcess Acquiring Control ProcessTree.TreeLock lock %08lX SHARED %08lX\n",
+                      "AFSIs64BitProcess Acquiring Control ProcessTree.TreeLock lock %p SHARED %08lX\n",
                       pDeviceExt->Specific.Control.ProcessTree.TreeLock,
-                      PsGetCurrentThread());
+                      PsGetCurrentThread()));
 
         AFSAcquireShared( pDeviceExt->Specific.Control.ProcessTree.TreeLock,
                           TRUE);
@@ -941,3 +943,74 @@ try_exit:
 
     return pThreadCB;
 }
+
+BOOLEAN
+AFSIsUser( IN PSID Sid)
+{
+    SECURITY_SUBJECT_CONTEXT subjectContext;
+    PTOKEN_USER user;
+    PACCESS_TOKEN token;
+    BOOLEAN retVal = FALSE;
+
+    SeCaptureSubjectContext( &subjectContext);
+    SeLockSubjectContext( &subjectContext);
+
+    token = SeQuerySubjectContextToken( &subjectContext);
+
+    if (NT_SUCCESS (SeQueryInformationToken( token, TokenUser, (PVOID*) &user)))
+    {
+
+        retVal = RtlEqualSid( user->User.Sid, Sid);
+
+        ExFreePool( user );
+    }
+    SeUnlockSubjectContext( &subjectContext);
+    SeReleaseSubjectContext( &subjectContext);
+    return retVal;
+}
+
+BOOLEAN
+AFSIsInGroup(PSID Sid)
+{
+    SECURITY_SUBJECT_CONTEXT subjectContext;
+    PTOKEN_GROUPS groups;
+    PACCESS_TOKEN token;
+    BOOLEAN retVal = FALSE;
+
+    SeCaptureSubjectContext( &subjectContext );
+    SeLockSubjectContext( &subjectContext );
+
+    token = SeQuerySubjectContextToken( &subjectContext );
+
+    if (NT_SUCCESS(SeQueryInformationToken(token, TokenGroups, (PVOID*) &groups)))
+    {
+        ULONG i;
+        for (i = 0; !retVal && i < groups->GroupCount; i++)
+        {
+            retVal = RtlEqualSid(Sid, groups->Groups[i].Sid);
+        }
+
+        ExFreePool( groups );
+    }
+    SeUnlockSubjectContext( &subjectContext );
+    SeReleaseSubjectContext( &subjectContext );
+    return retVal;
+}
+
+VOID
+AFSRegisterService( void)
+{
+    AFSServicePid = PsGetCurrentProcessId();
+}
+
+VOID
+AFSDeregisterService( void)
+{
+    AFSServicePid = NULL;
+}
+
+BOOLEAN
+AFSIsService( void)
+{
+    return PsGetCurrentProcessId() == AFSServicePid;
+}
