@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -35,7 +35,7 @@
 static char* whoami;
 
 
-static int DoVptList(struct cmd_syndesc *as, char *arock)
+static int DoVptList(struct cmd_syndesc *as, void *arock)
 {
     struct vpt_iter vpiter;
     struct vptab vpentry;
@@ -51,7 +51,7 @@ static int DoVptList(struct cmd_syndesc *as, char *arock)
     return 0;
 }
 
-static int DoVptAdd(struct cmd_syndesc *as, char *arock)
+static int DoVptAdd(struct cmd_syndesc *as, void *arock)
 {
     char *vpName, *vpDev;
     struct vptab vpentry;
@@ -79,7 +79,7 @@ static int DoVptAdd(struct cmd_syndesc *as, char *arock)
     return 0;
 }
 
-static int DoVptDel(struct cmd_syndesc *as, char *arock)
+static int DoVptDel(struct cmd_syndesc *as, void *arock)
 {
     char *vpName;
 
@@ -98,7 +98,7 @@ static int DoVptDel(struct cmd_syndesc *as, char *arock)
 }
 
 
-static int DoDirGet(struct cmd_syndesc *as, char *arock)
+static int DoDirGet(struct cmd_syndesc *as, void *arock)
 {
     char *buf;
 
@@ -115,7 +115,7 @@ static int DoDirGet(struct cmd_syndesc *as, char *arock)
 }
 
 
-static int DoDirSet(struct cmd_syndesc *as, char *arock)
+static int DoDirSet(struct cmd_syndesc *as, void *arock)
 {
     long status;
     HKEY key;
@@ -143,15 +143,19 @@ static int DoDirSet(struct cmd_syndesc *as, char *arock)
 }
 
 
-static int DoBosCfg(struct cmd_syndesc *as, char *arock)
+static int DoBosCfg(struct cmd_syndesc *as, void *arock)
 {
-    char bosSvcPath[AFSDIR_PATH_MAX];
-    SC_HANDLE scmHandle, svcHandle;
+    char *bosSvcPath = NULL;
+    SC_HANDLE scmHandle = NULL, svcHandle = NULL;
+    int code;
 
     /* determine if using specified or default service binary path */
     if (as->parms[0].items) {
 	/* BOS control service binary path specified */
-	sprintf(bosSvcPath, "\"%s\"", as->parms[0].items->data);
+	if (asprintf(&bosSvcPath, "\"%s\"", as->parms[0].items->data) < 0) {
+	    afs_com_err(whoami, 0, "out of memory building binary path");
+	    return 1;
+	}
     } else {
 	/* no BOS control service binary path specified; check for default */
 	char *dirBuf;
@@ -161,10 +165,13 @@ static int DoBosCfg(struct cmd_syndesc *as, char *arock)
 		    "binary path not specified and AFS server installation directory not set");
 	    return 1;
 	}
-	sprintf(bosSvcPath, "\"%s%s/%s\"",
-		dirBuf,
-		AFSDIR_CANONICAL_SERVER_BIN_DIRPATH,
-		AFSREG_SVR_SVC_IMAGENAME_DATA);
+	if (asprintf(&bosSvcPath, "\"%s%s/%s\"",
+		     dirBuf,
+		     AFSDIR_CANONICAL_SERVER_BIN_DIRPATH,
+		     AFSREG_SVR_SVC_IMAGENAME_DATA) < 0) {
+	    afs_com_err(whoami, 0, "out of memory building binary path");
+	    return 1;
+	}
     }
 
     /* create BOS control service */
@@ -178,7 +185,8 @@ static int DoBosCfg(struct cmd_syndesc *as, char *arock)
 	    reason = "(insufficient privilege)";
 	}
 	afs_com_err(whoami, 0, "unable to connect to the SCM %s", reason);
-	return 1;
+	code = 1;
+	goto out;
     }
 
     svcHandle = CreateService(scmHandle,
@@ -203,17 +211,22 @@ static int DoBosCfg(struct cmd_syndesc *as, char *arock)
 	    reason = "(service or display name already exists)";
 	}
 	afs_com_err(whoami, 0, "unable to create service %s", reason);
-	CloseServiceHandle(scmHandle);
-	return 1;
+	code = 1;
+    } else {
+	code = 0;
     }
 
-    CloseServiceHandle(svcHandle);
-    CloseServiceHandle(scmHandle);
-    return (0);
+out:
+    free(bosSvcPath);
+    if (svcHandle != NULL)
+	CloseServiceHandle(svcHandle);
+    if (scmHandle != NULL)
+	CloseServiceHandle(scmHandle);
+    return code;
 }
 
 
-static int DoBosDel(struct cmd_syndesc *as, char *arock)
+static int DoBosDel(struct cmd_syndesc *as, void *arock)
 {
     int rc = 0;
     SC_HANDLE scmHandle, svcHandle;
@@ -258,7 +271,7 @@ static int DoBosDel(struct cmd_syndesc *as, char *arock)
     return (rc);
 }
 
-static int DoVersionGet(struct cmd_syndesc *as, char *arock)
+static int DoVersionGet(struct cmd_syndesc *as, void *arock)
 {
     unsigned major, minor, patch;
 
@@ -286,15 +299,15 @@ SetupVptCmd(void)
 {
     struct cmd_syndesc	*ts;
 
-    ts = cmd_CreateSyntax("vptlist", DoVptList, 0,
+    ts = cmd_CreateSyntax("vptlist", DoVptList, NULL, 0,
 			  "list vice partition table");
 
-    ts = cmd_CreateSyntax("vptadd", DoVptAdd, 0,
+    ts = cmd_CreateSyntax("vptadd", DoVptAdd, NULL, 0,
 			  "add entry to vice partition table");
     cmd_AddParm(ts, "-partition", CMD_SINGLE, CMD_REQUIRED, "partition name");
     cmd_AddParm(ts, "-dev", CMD_SINGLE, CMD_REQUIRED, "device name");
 
-    ts = cmd_CreateSyntax("vptdel", DoVptDel, 0,
+    ts = cmd_CreateSyntax("vptdel", DoVptDel, NULL, 0,
 			  "remove entry from vice partition table");
     cmd_AddParm(ts, "-partition", CMD_SINGLE, CMD_REQUIRED, "partition name");
 }
@@ -304,10 +317,10 @@ SetupDirCmd(void)
 {
     struct cmd_syndesc	*ts;
 
-    ts = cmd_CreateSyntax("dirget", DoDirGet, 0,
+    ts = cmd_CreateSyntax("dirget", DoDirGet, NULL, 0,
 			  "display the AFS server installation directory");
 
-    ts = cmd_CreateSyntax("dirset", DoDirSet, 0,
+    ts = cmd_CreateSyntax("dirset", DoDirSet, NULL, 0,
 			  "set the AFS server installation directory");
     cmd_AddParm(ts, "-path", CMD_SINGLE, CMD_REQUIRED, "directory path");
 }
@@ -317,11 +330,11 @@ SetupBosCmd(void)
 {
     struct cmd_syndesc	*ts;
 
-    ts = cmd_CreateSyntax("boscfg", DoBosCfg, 0,
+    ts = cmd_CreateSyntax("boscfg", DoBosCfg, NULL, 0,
 			  "configure the AFS BOS control service");
     cmd_AddParm(ts, "-path", CMD_SINGLE, CMD_OPTIONAL, "service binary path");
 
-    ts = cmd_CreateSyntax("bosdel", DoBosDel, 0,
+    ts = cmd_CreateSyntax("bosdel", DoBosDel, NULL, 0,
 			  "delete (unconfigure) the AFS BOS control service");
 }
 
@@ -330,7 +343,7 @@ SetupVersionCmd(void)
 {
     struct cmd_syndesc	*ts;
 
-    ts = cmd_CreateSyntax("version", DoVersionGet, 0,
+    ts = cmd_CreateSyntax("version", DoVersionGet, NULL, 0,
 			  "display AFS version information");
 }
 
