@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -11,7 +11,9 @@
 #include <ws2tcpip.h>
 
 extern "C" {
+#include <afsconfig.h>
 #include <afs/param.h>
+#include <roken.h>
 #include <afs/stds.h>
 #include <afs/cm.h>
 #include <rx/rxkad.h>
@@ -266,11 +268,12 @@ BOOL GeneralTab_OnApply (HWND hDlg, BOOL fForce, BOOL fComplainIfInvalid)
    BOOL fLogonAuthent = IsDlgButtonChecked (hDlg, IDC_LOGON);
    if (fLogonAuthent != g.Configuration.fLogonAuthent)
       {
-	   SetBitLogonOption(fLogonAuthent,LOGON_OPTION_INTEGRATED);
+      SetBitLogonOption(fLogonAuthent,LOGON_OPTION_INTEGRATED);
       g.Configuration.fLogonAuthent = fLogonAuthent;
       }
 
-   Config_SetTrayIconFlag (IsDlgButtonChecked (hDlg, IDC_TRAYICON));
+  if (GetDlgItem(hDlg, IDC_TRAYICON) != NULL)
+      Config_SetTrayIconFlag (IsDlgButtonChecked(hDlg, IDC_TRAYICON));
 
    if (g.fIsWinNT)
       {
@@ -673,8 +676,8 @@ BOOL fIsCellInCellServDB (LPCTSTR pszCell)
    ULONG code = cm_SearchCellRegistry(1, cellname, NULL, NULL, NULL, NULL);
    if (code == 0)
       fFound = TRUE;
-   if (!fFound && 
-       (code != CM_ERROR_FORCE_DNS_LOOKUP) && 
+   if (!fFound &&
+       (code != CM_ERROR_FORCE_DNS_LOOKUP) &&
        CSDB_ReadFile (&CellServDB, NULL))
    {
        if (CSDB_FindCell (&CellServDB, pszCell))
