@@ -18,6 +18,8 @@
 #include <assert.h>
 #include <stdio.h>
 
+#include "osi_internal.h"
+
 /* atomicity-providing critical sections */
 CRITICAL_SECTION osi_baseAtomicCS[OSI_MUTEXHASHSIZE];
 static long     atomicIndexCounter = 0;
@@ -35,7 +37,7 @@ void osi_BaseInit(void)
     int i;
 
     for(i=0; i<OSI_MUTEXHASHSIZE; i++)
-        InitializeCriticalSection(&osi_baseAtomicCS[i]);
+        InitializeCriticalSectionAndSpinCount(&osi_baseAtomicCS[i], 4000);
 
     if ((tls_LockRefH = TlsAlloc()) == TLS_OUT_OF_INDEXES)
         osi_panic("TlsAlloc(tls_LockRefH) failure", __FILE__, __LINE__);
@@ -43,7 +45,7 @@ void osi_BaseInit(void)
     if ((tls_LockRefT = TlsAlloc()) == TLS_OUT_OF_INDEXES)
         osi_panic("TlsAlloc(tls_LockRefT) failure", __FILE__, __LINE__);
 
-    InitializeCriticalSection(&lock_ref_CS);
+    InitializeCriticalSectionAndSpinCount(&lock_ref_CS, 4000);
 }
 
 void
@@ -195,7 +197,7 @@ void lock_ObtainWrite(osi_rwlock_t *lockp)
         osi_assert(lockp->readers == 0 && (lockp->flags & OSI_LOCKFLAG_EXCL));
     } else {
         /* if we're here, all clear to set the lock */
-        lockp->flags |= OSI_LOCKFLAG_EXCL;
+        _InterlockedOr(&lockp->flags, OSI_LOCKFLAG_EXCL);
         lockp->tid[0] = tid;
     }
     osi_assertx(lockp->readers == 0, "write lock readers present");
@@ -376,7 +378,7 @@ void lock_ReleaseWrite(osi_rwlock_t *lockp)
     osi_assertx(lockp->tid[0] == thrd_Current(), "write lock not held by current thread");
     lockp->tid[0] = 0;
 
-    lockp->flags &= ~OSI_LOCKFLAG_EXCL;
+    _InterlockedAnd( &lockp->flags, ~OSI_LOCKFLAG_EXCL);
     if (lockp->waiters) {
         osi_TSignalForMLs(&lockp->d.turn, 0, csp);
     }
@@ -405,7 +407,7 @@ void lock_ConvertWToR(osi_rwlock_t *lockp)
     osi_assertx(lockp->tid[0] == thrd_Current(), "write lock not held by current thread");
 
     /* convert write lock to read lock */
-    lockp->flags &= ~OSI_LOCKFLAG_EXCL;
+    _InterlockedAnd(&lockp->flags, ~OSI_LOCKFLAG_EXCL);
     lockp->tid[0] = 0;
     lockp->readers++;
 
@@ -452,7 +454,7 @@ void lock_ConvertRToW(osi_rwlock_t *lockp)
 
     if (--(lockp->readers) == 0) {
         /* convert read lock to write lock */
-        lockp->flags |= OSI_LOCKFLAG_EXCL;
+        _InterlockedOr(&lockp->flags, OSI_LOCKFLAG_EXCL);
         lockp->tid[0] = tid;
     } else {
         osi_assertx(lockp->readers > 0, "read lock underflow");
@@ -501,7 +503,7 @@ void lock_ObtainMutex(struct osi_mutex *lockp)
         osi_assert(lockp->flags & OSI_LOCKFLAG_EXCL);
     } else {
         /* if we're here, all clear to set the lock */
-        lockp->flags |= OSI_LOCKFLAG_EXCL;
+        _InterlockedOr(&lockp->flags, OSI_LOCKFLAG_EXCL);
         lockp->tid = thrd_Current();
     }
 
@@ -554,7 +556,7 @@ void lock_ReleaseMutex(struct osi_mutex *lockp)
     osi_assertx(lockp->flags & OSI_LOCKFLAG_EXCL, "mutex not held");
     osi_assertx(lockp->tid == thrd_Current(), "mutex not held by current thread");
 
-    lockp->flags &= ~OSI_LOCKFLAG_EXCL;
+    _InterlockedAnd(&lockp->flags, ~OSI_LOCKFLAG_EXCL);
     lockp->tid = 0;
     if (lockp->waiters) {
         osi_TSignalForMLs(&lockp->d.turn, 0, csp);
@@ -655,7 +657,7 @@ int lock_TryWrite(struct osi_rwlock *lockp)
     }
     else {
         /* if we're here, all clear to set the lock */
-        lockp->flags |= OSI_LOCKFLAG_EXCL;
+        _InterlockedOr(&lockp->flags, OSI_LOCKFLAG_EXCL);
         lockp->tid[0] = thrd_Current();
         i = 1;
     }
@@ -706,7 +708,7 @@ int lock_TryMutex(struct osi_mutex *lockp) {
     }
     else {
         /* if we're here, all clear to set the lock */
-        lockp->flags |= OSI_LOCKFLAG_EXCL;
+        _InterlockedOr(&lockp->flags, OSI_LOCKFLAG_EXCL);
         lockp->tid = thrd_Current();
         i = 1;
     }
@@ -817,7 +819,7 @@ void osi_SleepW(LONG_PTR sleepVal, struct osi_rwlock *lockp)
 
     osi_assertx(lockp->flags & OSI_LOCKFLAG_EXCL, "osi_SleepW: not held");
 
-    lockp->flags &= ~OSI_LOCKFLAG_EXCL;
+    _InterlockedAnd(&lockp->flags, ~OSI_LOCKFLAG_EXCL);
     lockp->tid[0] = 0;
     if (lockp->waiters) {
         osi_TSignalForMLs(&lockp->d.turn, 0, NULL);
@@ -862,7 +864,7 @@ void osi_SleepM(LONG_PTR sleepVal, struct osi_mutex *lockp)
 
     osi_assertx(lockp->flags & OSI_LOCKFLAG_EXCL, "osi_SleepM not held");
 
-    lockp->flags &= ~OSI_LOCKFLAG_EXCL;
+    _InterlockedAnd(&lockp->flags, ~OSI_LOCKFLAG_EXCL);
     lockp->tid = 0;
     if (lockp->waiters) {
         osi_TSignalForMLs(&lockp->d.turn, 0, NULL);
