@@ -1,7 +1,7 @@
-/* 
+/*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -12,15 +12,11 @@
 #include <afs/param.h>
 #include <afs/stds.h>
 
-#ifndef DJGPP
 #include <windows.h>
 #include <rpc.h>
-#endif /* !DJGPP */
 #include <malloc.h>
 #include "osi.h"
-#ifndef DJGPP
 #include "dbrpc.h"
-#endif /* !DJGPP */
 #include <stdio.h>
 #include <assert.h>
 #include <WINNT\afsreg.h>
@@ -48,9 +44,7 @@ DWORD osi_TraceOption=0;
 
 osi_fdOps_t osi_logFDOps = {
 	osi_LogFDCreate,
-#ifndef DJGPP
         osi_LogFDGetInfo,
-#endif
         osi_LogFDClose
 };
 
@@ -63,8 +57,7 @@ osi_log_t *osi_LogCreate(char *namep, size_t size)
         LARGE_INTEGER bigFreq;
         LARGE_INTEGER bigTemp;
         LARGE_INTEGER bigJunk;
-	
-#ifndef DJGPP
+
 	if (osi_Once(&osi_logOnce)) {
 		QueryPerformanceFrequency(&bigFreq);
                 if (bigFreq.LowPart == 0 && bigFreq.HighPart == 0)
@@ -86,7 +79,6 @@ osi_log_t *osi_LogCreate(char *namep, size_t size)
 		/* done with init */
 		osi_EndOnce(&osi_logOnce);
         }
-#endif /* !DJGPP */
 
         logp = malloc(sizeof(osi_log_t));
         memset(logp, 0, sizeof(osi_log_t));
@@ -109,14 +101,13 @@ osi_log_t *osi_LogCreate(char *namep, size_t size)
 	logp->maxstringindex = size/3;
 	logp->stringindex = 0;
 	logp->stringsp = malloc(logp->maxstringindex * OSI_LOG_STRINGSIZE);
- 
+
         /* and sync */
         thrd_InitCrit(&logp->cs);
-        
+
 	StringCbCopyA(tbuffer, sizeof(tbuffer), "log:");
         StringCbCatA(tbuffer, sizeof(tbuffer), namep);
 	typep = osi_RegisterFDType(tbuffer, &osi_logFDOps, logp);
-#ifndef DJGPP
 	if (typep) {
 		/* add formatting info */
 		osi_AddFDFormatInfo(typep, OSI_DBRPC_REGIONINT, 0,
@@ -124,15 +115,14 @@ osi_log_t *osi_LogCreate(char *namep, size_t size)
 		osi_AddFDFormatInfo(typep, OSI_DBRPC_REGIONSTRING, 1,
 			"Time (mics)", 0);
 	}
-#endif
-	
+
         return logp;
 }
 
-/* we just panic'd.  Turn off all logging adding special log record
- * to all enabled logs.  Be careful not to wait for a lock.
+/* we just panic'd.  Log the error to all enabled log files.
+ * Be careful not to wait for a lock.
  */
-void osi_LogPanic(char *filep, size_t lineNumber)
+void osi_LogPanic(char *msgp, char *filep, size_t lineNumber)
 {
 	osi_log_t *tlp;
 
@@ -141,10 +131,10 @@ void osi_LogPanic(char *filep, size_t lineNumber)
 
 		/* otherwise, proceed */
 		if (filep)
-	                osi_LogAdd(tlp, "**PANIC** (file %s:%d)", (size_t) filep, lineNumber, 0, 0);
+	                osi_LogAdd(tlp, "**PANIC** \"%s\" (file %s:%d)", (size_t)msgp, (size_t) filep, lineNumber, 0, 0);
 		else
-			osi_LogAdd(tlp, "**PANIC**", 0, 0, 0, 0);
-		
+			osi_LogAdd(tlp, "**PANIC** \"%s\"", (size_t)msgp, 0, 0, 0, 0);
+
                 /* should grab lock for this, but we're in panic, and better safe than
                  * sorry.
                  */
@@ -176,67 +166,78 @@ void osi_LogFree(osi_log_t *logp)
 }
 
 /* add an element to a log */
-void osi_LogAdd(osi_log_t *logp, char *formatp, size_t p0, size_t p1, size_t p2, size_t p3)
+static void
+osi_IntLogAdd(osi_log_t *logp, int debug, char *formatp, size_t p0, size_t p1, size_t p2, size_t p3, size_t p4)
 {
 	osi_logEntry_t *lep;
         long ix;
         LARGE_INTEGER bigTime;
 
 	/* handle init races */
-	if (!logp) return;
+	if (!logp)
+            return;
 
 	/* do this w/o locking for speed; it is obviously harmless if we're off
          * by a bit.
          */
-	if (!logp->enabled) return;
-        
-	thrd_EnterCrit(&logp->cs);
-	if (logp->nused < logp->alloc) logp->nused++;
-	else {
-        	logp->first++;
-                if (logp->first >= logp->alloc) logp->first -= logp->alloc;
-        }
-        ix = logp->first + logp->nused - 1;
-        if (ix >= logp->alloc) ix -= logp->alloc;
+        if (logp->enabled) {
 
-        lep = logp->datap + ix;	/* ptr arith */
-        lep->tid = thrd_Current();
+		thrd_EnterCrit(&logp->cs);
+		if (logp->nused < logp->alloc)
+	            logp->nused++;
+		else {
+	            logp->first++;
+	            if (logp->first >= logp->alloc)
+	                logp->first -= logp->alloc;
+	        }
+	        ix = logp->first + logp->nused - 1;
+	        if (ix >= logp->alloc)
+	            ix -= logp->alloc;
 
-	/* get the time, using the high res timer if available */
-#ifndef DJGPP
-        if (osi_logFreq) {
-		QueryPerformanceCounter(&bigTime);
-		lep->micros = (bigTime.LowPart / osi_logFreq) * osi_logTixToMicros;
-        }
-        else lep->micros = GetCurrentTime() * 1000;
-#else
-        lep->micros = gettime_us();
-#endif /* !DJGPP */                
+	        lep = logp->datap + ix;	/* ptr arith */
+	        lep->tid = thrd_Current();
 
-        lep->formatp = formatp;
-        lep->parms[0] = p0;
-        lep->parms[1] = p1;
-        lep->parms[2] = p2;
-        lep->parms[3] = p3;
+		/* get the time, using the high res timer if available */
+	        if (osi_logFreq) {
+			QueryPerformanceCounter(&bigTime);
+			lep->micros = (bigTime.LowPart / osi_logFreq) * osi_logTixToMicros;
+	        }
+	        else lep->micros = GetCurrentTime() * 1000;
 
+	        lep->formatp = formatp;
+	        lep->parms[0] = p0;
+	        lep->parms[1] = p1;
+	        lep->parms[2] = p2;
+	        lep->parms[3] = p3;
+	        lep->parms[4] = p4;
 #ifdef NOTSERVICE
-        printf( "%9ld:", lep->micros );
-        printf( formatp, p0, p1, p2, p3);
-        printf( "\n" );
+	        printf( "%9ld:", lep->micros );
+	        printf( formatp, p0, p1, p2, p3, p4);
+	        printf( "\n" );
 #endif
+                thrd_LeaveCrit(&logp->cs);
+        }
 
-        if(ISCLIENTDEBUGLOG(osi_TraceOption)) {
+        if (debug || (logp->enabled && ISCLIENTDEBUGLOG(osi_TraceOption))) {
 	    char wholemsg[1024], msg[1000];
 
 	    StringCbPrintfA(msg, sizeof(msg), formatp,
-                            p0, p1, p2, p3);
-	    StringCbPrintfA(wholemsg, sizeof(wholemsg), 
+                            p0, p1, p2, p3, p4);
+	    StringCbPrintfA(wholemsg, sizeof(wholemsg),
                             "tid[%d] %s\n",
-                            lep->tid, msg);
+                            thrd_Current(), msg);
             OutputDebugStringA(wholemsg);
         }
+}
 
-	thrd_LeaveCrit(&logp->cs);
+void osi_LogAdd(osi_log_t *logp, char *formatp, size_t p0, size_t p1, size_t p2, size_t p3, size_t p4)
+{
+    osi_IntLogAdd(logp, FALSE, formatp, p0, p1, p2, p3, p4);
+}
+
+void osi_DebugAdd(osi_log_t *logp, char *formatp, size_t p0, size_t p1, size_t p2, size_t p3, size_t p4)
+{
+    osi_IntLogAdd(logp, TRUE, formatp, p0, p1, p2, p3, p4);
 }
 
 void osi_LogPrint(osi_log_t *logp, FILE_HANDLE handle)
@@ -255,7 +256,8 @@ void osi_LogPrint(osi_log_t *logp, FILE_HANDLE handle)
 		lep = logp->datap + ix;		/* pointer arithmetic */
 		StringCbPrintfA(msg, sizeof(msg), lep->formatp,
                                 lep->parms[0], lep->parms[1],
-                                lep->parms[2], lep->parms[3]);
+                                lep->parms[2], lep->parms[3],
+                                lep->parms[4]);
 		StringCbPrintfA(wholemsg, sizeof(wholemsg),
                                 "time %d.%06d, tid %d %s\r\n",
                                 lep->micros / 1000000,
@@ -334,7 +336,7 @@ long osi_LogFDCreate(osi_fdType_t *typep, osi_fd_t **outpp)
 {
 	osi_logFD_t *lfdp;
 	osi_log_t *logp;
-        
+
         lfdp = malloc(sizeof(*lfdp));
         logp = lfdp->logp = typep->rockp;	/* the log we were created for */
         thrd_EnterCrit(&logp->cs);
@@ -354,13 +356,13 @@ long osi_LogFDGetInfo(osi_fd_t *ifd, osi_remGetInfoParms_t *outp)
     osi_logEntry_t *lep;
     char tbuffer[256];
     long ix;
-        
+
     lfdp = (osi_logFD_t *) ifd;
     logp = lfdp->logp;
-        
+
     /* see if we're done */
     if (lfdp->current >= lfdp->nused) return OSI_DBRPC_EOF;
-        
+
     /* grab lock */
     thrd_EnterCrit(&logp->cs);
 
@@ -371,7 +373,7 @@ long osi_LogFDGetInfo(osi_fd_t *ifd, osi_remGetInfoParms_t *outp)
     lep = logp->datap + ix;	/* ptr arith to current index */
 
     StringCbPrintfA(tbuffer, sizeof(tbuffer), lep->formatp, lep->parms[0], lep->parms[1],
-                    lep->parms[2], lep->parms[3]);
+                    lep->parms[2], lep->parms[3], lep->parms[4]);
 
     /* now copy out info */
     StringCbCopyA(outp->sdata[0], sizeof(outp->sdata[0]), tbuffer);
@@ -416,9 +418,9 @@ void osi_InitTraceOption()
 
 
 #define MAXBUF_ 131
-void osi_LogEvent0(char *a,char *b) 
+void osi_LogEvent0(char *a,char *b)
 {
-	HANDLE h; 
+	HANDLE h;
     char *ptbuf[1];
 	if (!ISCLIENTTRACE(osi_TraceOption))
 		return;
@@ -429,7 +431,7 @@ void osi_LogEvent0(char *a,char *b)
 }
 
 
-void osi_LogEvent(char *a,char *b,char *c,...) 
+void osi_LogEvent(char *a,char *b,char *c,...)
 {
 	HANDLE h; char *ptbuf[1],buf[MAXBUF_+1];
 	va_list marker;
@@ -450,7 +452,7 @@ char *osi_HexifyString(char *s) {
 	char *buf, *counter, *bufp;
 
 	len = strlen(s);
-	
+
 	bufp = buf = malloc( len * 3 ); /* [xx.xx.xx.xx\0] */
 
 	if(!buf) return NULL;
