@@ -15,8 +15,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/DARWIN/osi_inode.c,v 1.8.4.1 2008/11/29 18:20:26 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afsincludes.h"	/* Afs-based standard headers */
@@ -25,7 +23,7 @@ RCSID
 #ifndef AFS_DARWIN80_ENV
 #include <ufs/ufs/ufsmount.h>
 #endif
-extern struct ucred afs_osi_cred;
+extern struct ucred *afs_osi_credp;
 extern int afs_CacheFSType;
 
 #ifdef AFS_DARWIN80_ENV
@@ -40,10 +38,14 @@ getinode(fs, dev, inode, vpp, perror)
     int code;
     vfs_context_t ctx;
     char volfspath[64];
+    size_t len = sizeof(volfspath);
     
     *vpp = 0;
     *perror = 0;
-    sprintf(volfspath, "/.vol/%d/%d", dev, inode);
+    if (snprintf(volfspath, len, "/.vol/%d/%d", dev, inode) >= len) {
+	*perror = BAD_IGET;
+	return ENAMETOOLONG;
+    }
     code = vnode_open(volfspath, O_RDWR, 0, 0, &vp, afs_osi_ctxtp);
     if (code) {
 	*perror = BAD_IGET;
@@ -65,7 +67,7 @@ igetinode(vfsp, dev, inode, vpp, va, perror)
 {
     vnode_t pvp, vp;
     extern struct osi_dev cacheDev;
-    register int code = 0;
+    int code = 0;
     
     *perror = 0;
     
@@ -118,12 +120,12 @@ getinode(fs, dev, inode, vpp, perror)
     *vpp = 0;
     *perror = 0;
     if (!fs) {
-	register struct ufsmount *ump;
+	struct ufsmount *ump;
 #ifdef VFSTOHFS
-	register struct hfsmount *hmp;
+	struct hfsmount *hmp;
 #endif
-	register struct vnode *vp;
-	register struct mount *mp;
+	struct vnode *vp;
+	struct mount *mp;
 	extern struct mount *rootfs;
 	if (mp = rootfs)
 	    do {
@@ -141,10 +143,6 @@ getinode(fs, dev, inode, vpp, perror)
 #ifdef VFSTOHFS
 		if (!strcmp(mp->mnt_vfc->vfc_name, "hfs")) {
 		    hmp = VFSTOHFS(mp);
-#if 0
-		    if (hmp->hfs_mp == NULL)
-			break;
-#endif
 		    if (hmp->hfs_raw_dev == dev) {
 			fs = hmp->hfs_mp;
 		    }
@@ -176,7 +174,7 @@ igetinode(vfsp, dev, inode, vpp, va, perror)
 {
     struct vnode *pvp, *vp;
     extern struct osi_dev cacheDev;
-    register int code = 0;
+    int code = 0;
 
     *perror = 0;
 
@@ -189,7 +187,7 @@ igetinode(vfsp, dev, inode, vpp, va, perror)
 	iforget(vp);
 	return (ENOENT);
     }
-    VOP_GETATTR(vp, va, &afs_osi_cred, current_proc());
+    VOP_GETATTR(vp, va, afs_osi_credp, current_proc());
     if (va->va_mode == 0) {
 	/* Not an allocated inode */
 	iforget(vp);
@@ -219,14 +217,7 @@ iforget(vp)
     if (vp->v_usecount == 1) {
 	vp->v_usecount = 0;
 	VOP_UNLOCK(vp, 0, current_proc());
-#if 0
-	simple_lock(&vnode_free_list_slock);
-	TAILQ_INSERT_TAIL(&vnode_free_list, vp, v_freelist);
-	freevnodes++;
-	simple_unlock(&vnode_free_list_slock);
-#else
 	printf("iforget: leaking vnode\n");
-#endif
     } else {
 	vput(vp);
     }
@@ -237,17 +228,17 @@ int
 afs_syscall_icreate(long dev, long near_inode, long param1, long param2, 
 		    long param3, long param4, long *retval)
 {
-    return EOPNOTSUPP;
+    return ENOTSUP;
 }
 
 int
 afs_syscall_iopen(int dev, int inode, int usrmod, long *retval)
 {
-    return EOPNOTSUPP;
+    return ENOTSUP;
 }
 
 int
 afs_syscall_iincdec(int dev, int inode, int inode_p1, int amount)
 {
-    return EOPNOTSUPP;
+    return ENOTSUP;
 }
