@@ -173,6 +173,18 @@ Bind(afs_uint32 server)
     return (curr_fromconn);
 }
 
+static int
+ListOneVolume(struct rx_connection *aconn, afs_int32 apart, afs_uint32 avolid,
+	      volEntries *entries)
+{
+    afs_int32 code;
+    code = AFSVolListOneVolume(aconn, apart, avolid, entries);
+    if (code == 0 && entries->volEntries_len != 1) {
+	code = VOLSERFAILEDOP;
+    }
+    return code;
+}
+
 /* notes
  * 1) save the chunksize or otherwise ensure tape space remaining is
  *	check frequently enough
@@ -217,8 +229,7 @@ dumpVolume(struct tc_dumpDesc * curDump, struct dumpRock * dparamsPtr)
     /* Determine when the volume was last cloned and updated */
     volumeInfo.volEntries_val = (volintInfo *) 0;
     volumeInfo.volEntries_len = 0;
-    rc = AFSVolListOneVolume(fromconn, curDump->partition, curDump->vid,
-			     &volumeInfo);
+    rc = ListOneVolume(fromconn, curDump->partition, curDump->vid, &volumeInfo);
     if (rc)
 	ERROR_EXIT(rc);
     updatedate = volumeInfo.volEntries_val[0].updateDate;
@@ -543,8 +554,7 @@ xbsaDumpVolume(struct tc_dumpDesc * curDump, struct dumpRock * dparamsPtr)
     /* Determine when the volume was last cloned and updated */
     volumeInfo.volEntries_val = (volintInfo *) 0;
     volumeInfo.volEntries_len = 0;
-    rc = AFSVolListOneVolume(fromconn, curDump->partition, curDump->vid,
-			     &volumeInfo);
+    rc = ListOneVolume(fromconn, curDump->partition, curDump->vid, &volumeInfo);
     if (rc)
 	ERROR_EXIT(rc);
     updatedate = volumeInfo.volEntries_val[0].updateDate;
@@ -868,8 +878,7 @@ dumpPass(struct dumpRock * dparamsPtr, int passNumber)
 		    dparamsPtr->volumesFailed++;
 		    continue;
 		}
-		/* Fall into RWVOL case */
-
+		AFS_FALLTHROUGH;
 	    case RWVOL:
 		for (e = 0; e < vldbEntry.nServers; e++) {	/* Find the RW volume */
 		    if (vldbEntry.serverFlags[e] & VLSF_RWVOL)
@@ -2112,10 +2121,12 @@ DeleteDump(void *param)
 
     /* Query the backup database for list of volumes to delete */
     for (index = next = 0; index != -1; index = next) {
-	rc = ubik_Call_SingleServer(BUDB_GetVolumes, udbHandle.uh_client,
-				    UF_SINGLESERVER, BUDB_MAJORVERSION,
-				    BUDB_OP_DUMPID, tapeName, dumpid, 0,
-				    index, &next, &dbTime, &vl);
+	rc = ubik_Call_SingleServer_BUDB_GetVolumes(udbHandle.uh_client,
+						    UF_SINGLESERVER,
+						    BUDB_MAJORVERSION,
+						    BUDB_OP_DUMPID,
+						    tapeName, dumpid, 0, index,
+						    &next, &dbTime, &vl);
 	if (rc) {
 	    if (rc == BUDB_ENDOFLIST)
 		break;
