@@ -1,5 +1,5 @@
 /*
- * Thanks to Jim Rees and University of Michigan CITI, for the initial 
+ * Thanks to Jim Rees and University of Michigan CITI, for the initial
  * OpenBSD porting work.
  */
 
@@ -13,7 +13,6 @@
 #define AFS_XBSD_ENV		1	/* {Free,Open,Net}BSD */
 
 #define AFS_NAMEI_ENV		1	/* User space interface to file system */
-#define AFS_64BIT_ENV		1
 #define AFS_64BIT_CLIENT	1
 #define AFS_64BIT_IOPS_ENV	1	/* Needed for NAMEI */
 
@@ -29,15 +28,14 @@
 #define AFS_OBSD39_ENV		1
 #define AFS_OBSD40_ENV		1
 
+#undef  AFS_NONFSTRANS
 #define AFS_NONFSTRANS		1
-#define AFS_VM_RDWR_ENV		1
 #define AFS_VFS_ENV		1
 #define AFS_VFSINCL_ENV		1
 
 #define FTRUNC O_TRUNC
 
 #define AFS_SYSCALL		208
-#define AFS_MOUNT_AFS		"afs"
 
 #define RXK_LISTENER_ENV	1
 #define AFS_GCPAGS	        0	/* if nonzero, garbage collect PAGs */
@@ -50,18 +48,9 @@
 /* Extra kernel definitions (from kdefs file) */
 #ifdef _KERNEL
 #define AFS_GLOBAL_SUNLOCK	1
-#define	AFS_SHORTGID		0	/* are group id's short? */
 
 #if	!defined(ASSEMBLER) && !defined(__LANGUAGE_ASSEMBLY__)
 enum vcexcl { NONEXCL, EXCL };
-
-#ifndef MIN
-#define MIN(A,B) ((A) < (B) ? (A) : (B))
-#endif
-#ifndef MAX
-#define MAX(A,B) ((A) > (B) ? (A) : (B))
-#endif
-
 #endif /* ! ASSEMBLER & ! __LANGUAGE_ASSEMBLY__ */
 #endif /* _KERNEL */
 
