@@ -29,12 +29,6 @@
 #include <afs/afs_clientAdmin.h>
 #include <afs/afs_utilAdmin.h>
 
-#ifdef AFS_DARWIN_ENV
-pthread_mutex_t des_init_mutex = PTHREAD_MUTEX_INITIALIZER;
-pthread_mutex_t des_random_mutex = PTHREAD_MUTEX_INITIALIZER;
-pthread_mutex_t rxkad_random_mutex = PTHREAD_MUTEX_INITIALIZER;
-#endif /* AFS_DARWIN_ENV */
-
 void
 Usage(void)
 {
