@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -10,6 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
+#include <roken.h>
 
 #ifndef RXDEBUG
 char rxi_tracename[80] = "\0Tracing not compiled in";
@@ -21,18 +22,16 @@ main(int argc, char **argv)
 }
 #endif
 #else
-#include <string.h>
-#ifdef AFS_NT40_ENV
-#include <fcntl.h>
-#include <io.h>
-#else
-#include <sys/file.h>
-#include <unistd.h>
-#endif
+
 #include "rx.h"
+#include "rx_atomic.h"
 #include "rx_globals.h"
+#include "rx_internal.h"
 #include "rx_trace.h"
 
+#include "rx_conn.h"
+#include "rx_call.h"
+
 #ifdef RXTRACEON
 char rxi_tracename[80] = "/tmp/rxcalltrace";
 #else
@@ -56,9 +55,14 @@ struct rx_trace {
 void
 rxi_flushtrace(void)
 {
-    if (rxi_logfd >= 0)
-	write(rxi_logfd, rxi_tracebuf, rxi_tracepos);
+    afs_uint32 len = rxi_tracepos;
+
     rxi_tracepos = 0;
+    if (rxi_logfd < 0)
+	return;
+    if (write(rxi_logfd, rxi_tracebuf, len) < 0) {
+	/* don't care */
+    }
 }
 
 void
@@ -81,7 +85,7 @@ rxi_calltrace(unsigned int event, struct rx_call *call)
     rxtinfo.now = now.sec * 1000 + now.usec / 1000;
     rxtinfo.cid = call->conn->cid;
     rxtinfo.call = *(call->callNumber);
-    rxtinfo.qlen = rx_nWaiting;
+    rxtinfo.qlen = rx_atomic_read(&rx_nWaiting);
     rxtinfo.servicetime = 0;
     rxtinfo.waittime = 0;
 
@@ -118,6 +122,8 @@ rxi_calltrace(unsigned int event, struct rx_call *call)
 
     case RX_CALL_ARRIVAL:
 	call->traceWait = now;
+	break;
+
     default:
 	break;
     }
@@ -129,7 +135,6 @@ rxi_calltrace(unsigned int event, struct rx_call *call)
 }
 
 #ifdef DUMPTRACE
-#include <errno.h>
 #ifdef AFS_NT40_ENV
 #include <afs/afsutil.h>
 #endif
