@@ -13,31 +13,19 @@
 #include <afs/param.h>
 #include <roken.h>
 
-#include <sys/types.h>
-#include <stdio.h>
-#ifdef AFS_NT40_ENV
-#include <io.h>
-#include <winsock2.h>
-#include <fcntl.h>
-#include <stdlib.h>
-#else
-#include <netinet/in.h>
-#include <netdb.h>
+#ifdef HAVE_SYS_FILE_H
 #include <sys/file.h>
 #endif
-#include <sys/stat.h>
-#include <signal.h>
 
 #include <afs/opr.h>
 #include <rx/rx_clock.h>
 #include <rx/rx.h>
 #include <rx/rx_globals.h>
 #include <rx/rx_null.h>
-#include <errno.h>
 #include <afs/afsutil.h>
 
 #ifndef osi_Alloc
-#define osi_Alloc(n) (char *) malloc(n)
+#define osi_Alloc(n) malloc(n)
 #endif
 
 int timeReadvs = 0;
@@ -69,7 +57,7 @@ quitSignal(int ignore)
 	rx_PrintStats(debugFile);
 }
 
-#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX20_ENV)
+#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX_ENV)
 int
 test_syscall(afs_uint32 a3, afs_uint32 a4, void *a5)
 {
@@ -103,7 +91,7 @@ main(int argc, char **argv)
     int setFD = 0;
     int jumbo = 0;
 
-#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX20_ENV)
+#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX_ENV)
     setlinebuf(stdout);
     rxi_syscallp = test_syscall;
 #endif
@@ -230,7 +218,7 @@ main(int argc, char **argv)
     if (sendFile)
 	SendFile(sendFile, conn);
     else {
-	buffer = (char *)osi_Alloc(bufferSize);
+	buffer = osi_Alloc(bufferSize);
 	while (nCalls--) {
 	    struct clock startTime;
 	    struct timeval t;
@@ -335,7 +323,7 @@ SendFile(char *file, struct rx_connection *conn)
     blockSize = status.st_blksize;
 #endif
 #endif
-    buf = (char *)osi_Alloc(blockSize);
+    buf = osi_Alloc(blockSize);
     bytesLeft = status.st_size;
     clock_GetTime(&startTime);
     call = rx_NewCall(conn);
@@ -421,7 +409,6 @@ Quit(char *msg)
  *
  * Open file descriptors until file descriptor n or higher is returned.
  */
-#include <sys/stat.h>
 void
 OpenFD(int n)
 {
