@@ -21,6 +21,7 @@
 #include <sys/systm.h>
 #endif
 
+#include <afs/opr.h>
 #include <rx/rx.h>
 #include <rx/xdr.h>
 #include <rx/rx_packet.h>
@@ -77,8 +78,8 @@ pthread_mutex_t rxkad_random_mutex
 = PTHREAD_MUTEX_INITIALIZER
 #endif
 ;
-#define LOCK_RM osi_Assert(pthread_mutex_lock(&rxkad_random_mutex)==0)
-#define UNLOCK_RM osi_Assert(pthread_mutex_unlock(&rxkad_random_mutex)==0)
+#define LOCK_RM opr_Verify(pthread_mutex_lock(&rxkad_random_mutex)==0)
+#define UNLOCK_RM opr_Verify(pthread_mutex_unlock(&rxkad_random_mutex)==0)
 #else
 #define LOCK_RM
 #define UNLOCK_RM
@@ -144,12 +145,12 @@ rxkad_NewServerSecurityObject(rxkad_level level, void *get_key_rock,
 	return 0;
 
     size = sizeof(struct rx_securityClass);
-    tsc = (struct rx_securityClass *)osi_Alloc(size);
+    tsc = rxi_Alloc(size);
     memset(tsc, 0, size);
     tsc->refCount = 1;		/* caller has one reference */
     tsc->ops = &rxkad_server_ops;
     size = sizeof(struct rxkad_sprivate);
-    tsp = (struct rxkad_sprivate *)osi_Alloc(size);
+    tsp = rxi_Alloc(size);
     memset(tsp, 0, size);
     tsc->privateData = (char *)tsp;
 
@@ -433,7 +434,7 @@ rxkad_CheckResponse(struct rx_securityClass *aobj,
 	    return RXKADNOAUTH;
     } else {			/* save the info for later retreival */
 	int size = sizeof(struct rxkad_serverinfo);
-	rock = (struct rxkad_serverinfo *)osi_Alloc(size);
+	rock = rxi_Alloc(size);
 	memset(rock, 0, size);
 	rock->kvno = kvno;
 	memcpy(&rock->client, &client, sizeof(rock->client));
