@@ -275,7 +275,7 @@ PrintCacheEntries32(struct rx_connection *aconn, int aint32)
 	    continue;
 
 	/* otherwise print this entry */
-	printf("** Cache entry @ 0x%08x for %d.%d.%d.%d", centry.addr,
+	printf("** Cache entry @ 0x%08x for %d.%u.%u.%u", centry.addr,
 	       centry.cell, centry.netFid.Volume, centry.netFid.Vnode,
 	       centry.netFid.Unique);
 
@@ -371,7 +371,7 @@ PrintCacheEntries64(struct rx_connection *aconn, int aint32)
 	    continue;
 
 	/* otherwise print this entry */
-	printf("** Cache entry @ 0x%08x for %d.%d.%d.%d", centry.addr,
+	printf("** Cache entry @ 0x%08x for %d.%u.%u.%u", centry.addr,
 	       centry.cell, centry.netFid.Volume, centry.netFid.Vnode,
 	       centry.netFid.Unique);
 
@@ -569,8 +569,8 @@ CommandProc(struct cmd_syndesc *as, void *arock)
 
     if (int32p == 0 || int32p == 1)
         PrintLocks(conn, int32p);
-    if (int32p >= 0 || int32p <= 4)
-        PrintCacheEntries(conn, int32p);
+
+    PrintCacheEntries(conn, int32p);
     return 0;
 }
 
@@ -607,7 +607,7 @@ main(int argc, char **argv)
 
     rx_Init(0);
 
-    ts = cmd_CreateSyntax(NULL, CommandProc, NULL, "query afs cache manager");
+    ts = cmd_CreateSyntax(NULL, CommandProc, NULL, 0, "query afs cache manager");
     cmd_AddParm(ts, "-servers", CMD_SINGLE, CMD_REQUIRED, "server machine");
     cmd_AddParm(ts, "-port", CMD_SINGLE, CMD_OPTIONAL, "IP port");
     cmd_AddParm(ts, "-long", CMD_FLAG, CMD_OPTIONAL, "print all info");
