@@ -24,17 +24,12 @@
 #include <afs/vice.h>
 #include <afs/sys_prototypes.h>
 
-#if defined(AFS_OSF_ENV) || defined(AFS_SGI61_ENV) || (defined(AFS_AIX51_ENV) && defined(AFS_64BIT_KERNEL))
 /* For SGI 6.2, this is changed to 1 if it's a 32 bit kernel. */
-int afs_icl_sizeofLong = 2;
-#else
-int afs_icl_sizeofLong = 1;
-#endif
+int afs_icl_sizeofLong = ICL_LONG;
 
-#if defined(AFS_SGI61_ENV) || (defined(AFS_AIX51_ENV) && defined(AFS_64BIT_KERNEL))
+#if ICL_LONG == 2
 int afs_64bit_kernel = 1;	/* Default for 6.2+, and always for 6.1 */
-extern int afs_icl_sizeofLong;	/* Used in ICL_SIZEHACK() */
-#ifdef AFS_SGI62_ENV
+#ifdef AFS_SGI_ENV
 
 /* If _SC_KERN_POINTERS not in sysconf, then we can assume a 32 bit abi. */
 void
@@ -53,8 +48,8 @@ set_kernel_sizeof_long(void)
     }
 }
 
-#endif /* AFS_SGI62_ENV */
-#endif /* AFS_SGI61_ENV */
+#endif /* AFS_SGI_ENV */
+#endif /* ICL_LONG == 2 */
 
 int afs_syscall(long call, long parm0, long parm1, long parm2, long parm3,
 		long parm4, long parm5, long parm6);
@@ -116,7 +111,7 @@ icl_GetSize(afs_int32 type, char *addr)
  * by typesp.  Also watch for prematurely running out of parameters
  * before the string is gone.
  */
-#if defined(AFS_SGI61_ENV) || (defined(AFS_AIX51_ENV) && defined(AFS_64BIT_KERNEL))
+#if ICL_LONG == 2
 static int
 CheckTypes(char *bufferp, int *typesp, int typeCount, char *outMsgBuffer)
 {
@@ -157,7 +152,7 @@ CheckTypes(char *bufferp, int *typesp, int typeCount, char *outMsgBuffer)
 	     * check the type descriptor.
 	     */
 	    inPercent = 0;
-	    if (tix > typeCount)
+	    if (tix >= typeCount)
 		return 0;	/* no more type descriptors left */
 	    if (tc == 's') {
 		if (typesp[tix] != 1)	/* not a string descriptor */
@@ -191,7 +186,7 @@ CheckTypes(char *bufferp, int *typesp, int typeCount, char *outMsgBuffer)
     }
     /* not reached */
 }
-#else /* AFS_SGI61_ENV */
+#else /* ICL_LONG == 2 */
 static int
 CheckTypes(char *bufferp, int *typesp, int typeCount)
 {
@@ -223,7 +218,7 @@ CheckTypes(char *bufferp, int *typesp, int typeCount)
 	     * check the type descriptor.
 	     */
 	    inPercent = 0;
-	    if (tix > typeCount)
+	    if (tix >= typeCount)
 		return 0;	/* no more type descriptors left */
 	    if (tc == 's' && typesp[tix] != 1)	/* not a string descriptor */
 		return 0;
@@ -236,27 +231,24 @@ CheckTypes(char *bufferp, int *typesp, int typeCount)
     }
     /* not reached */
 }
-#endif /* AFS_SGI61_ENV */
+#endif /* ICL_LONG == 2 */
 
 /* display a single record.
  * alp points at the first word in the array to be interpreted
  * rsize gives the # of words in the array
  */
-#if defined(AFS_SGI61_ENV) && !defined(AFS_SGI62_ENV)
-#define uint64_t long long
-#endif
 static void
 DisplayRecord(FILE *outFilep, afs_int32 *alp, afs_int32 rsize)
 {
     char msgBuffer[1024];
-#if defined(AFS_SGI61_ENV) || (defined(AFS_AIX51_ENV) && defined(AFS_64BIT_KERNEL))
+#if ICL_LONG == 2
     char outMsgBuffer[1024];
     uint64_t tempParam;
     uint64_t printfParms[ICL_MAXEXPANSION * /* max parms */ 4];
     char *printfStrings[ICL_MAXEXPANSION * /* max parms */ 4];
-#else /* AFS_SGI61_ENV */
+#else
     long printfParms[ICL_MAXEXPANSION * /* max parms */ 4];
-#endif /* AFS_SGI61_ENV */
+#endif
     int printfTypes[ICL_MAXEXPANSION * 4];
     int i;
     afs_int32 done = 0;
@@ -289,17 +281,14 @@ DisplayRecord(FILE *outFilep, afs_int32 *alp, afs_int32 rsize)
 	case ICL_TYPE_LONG:
 	case ICL_TYPE_POINTER:
 	    printfTypes[pftix++] = 0;
-#if defined(AFS_SGI61_ENV) || (defined(AFS_AIX51_ENV) && defined(AFS_64BIT_KERNEL))
+#if ICL_LONG == 2
 	    printfParms[pfpix] = alp[pix];
 	    printfParms[pfpix] &= 0xffffffff;
 	    if (afs_64bit_kernel) {
 		printfParms[pfpix] <<= 32;
 		printfParms[pfpix] |= alp[pix + 1];
 	    }
-#elif defined(AFS_OSF_ENV)
-	    printfParms[pfpix] = alp[pix + 1];
-	    printfParms[pfpix] |= (alp[pix] <<= 32);
-#else /* !AFS_OSF_ENV && !AFS_SGI61_ENV */
+#else
 	    printfParms[pfpix] = alp[pix];
 #endif
 	    pfpix++;
@@ -327,15 +316,11 @@ DisplayRecord(FILE *outFilep, afs_int32 *alp, afs_int32 rsize)
 	    break;
 	case ICL_TYPE_STRING:
 	    printfTypes[pftix++] = 1;
-#ifdef AFS_SGI64_ENV
+#if ICL_LONG == 2
 	    printfStrings[pfpix++] = (char *)&alp[pix];
-#else /* AFS_SGI64_ENV */
-#if defined(AFS_SGI61_ENV) || (defined(AFS_AIX51_ENV) && defined(AFS_64BIT_KERNEL))
-	    printfStrings[pfpix++] = (char *)&alp[pix];
-#else /* AFS_SGI61_ENV */
+#else
 	    printfParms[pfpix++] = (long)&alp[pix];
-#endif /* AFS_SGI61_ENV */
-#endif /* AFS_SGI64_ENV */
+#endif
 	    break;
 	case ICL_TYPE_UNIXDATE:
 	    tmv = alp[pix];
@@ -360,7 +345,7 @@ DisplayRecord(FILE *outFilep, afs_int32 *alp, afs_int32 rsize)
      */
     printed = 0;
     if (status == 0) {
-#if defined(AFS_SGI61_ENV) || (defined(AFS_AIX51_ENV) && defined(AFS_64BIT_KERNEL))
+#if ICL_LONG == 2
 	if (CheckTypes(msgBuffer, printfTypes, pftix, outMsgBuffer)) {
 	    /* we have a string to use, but it ends "(dfs / zcm)",
 	     * so we remove the extra gunk.
@@ -408,7 +393,7 @@ DisplayRecord(FILE *outFilep, afs_int32 *alp, afs_int32 rsize)
 	    fprintf(outFilep, "\n");
 	    printed = 1;
 	}
-#else /* AFS_SGI61_ENV */
+#else /* ICL_LONG == 2 */
 	if (CheckTypes(msgBuffer, printfTypes, pftix)) {
 	    /* we have a string to use, but it ends "(dfs / zcm)",
 	     * so we remove the extra gunk.
@@ -427,7 +412,7 @@ DisplayRecord(FILE *outFilep, afs_int32 *alp, afs_int32 rsize)
 	    fprintf(outFilep, "\n");
 	    printed = 1;
 	}
-#endif /* AFS_SGI61_ENV */
+#endif /* ICL_LONG == 2 */
 	else {
 	    fprintf(outFilep, "Type mismatch, using raw print.\n");
 	    fprintf(outFilep, "%s", msgBuffer);
@@ -454,24 +439,24 @@ DisplayRecord(FILE *outFilep, afs_int32 *alp, afs_int32 rsize)
 		    fprintf(outFilep, "p%d:%d ", i, alp[pix]);
 		    break;
 		case ICL_TYPE_LONG:
-#ifdef AFS_SGI61_ENV
+#if ICL_LONG == 2
 		    tempParam = alp[pix];
 		    tempParam <<= 32;
 		    tempParam |= alp[pix + 1];
 		    fprintf(outFilep, "p%d:%" AFS_INT64_FMT " ", i, tempParam);
-#else /* AFS_SGI61_ENV */
+#else
 		    fprintf(outFilep, "p%d:%d ", i, alp[pix]);
-#endif /* AFS_SGI61_ENV */
+#endif
 		    break;
 		case ICL_TYPE_POINTER:
-#ifdef AFS_SGI61_ENV
+#if ICL_LONG == 2
 		    tempParam = alp[pix];
 		    tempParam <<= 32;
 		    tempParam |= alp[pix + 1];
 		    fprintf(outFilep, "p%d:0x%llx ", i, tempParam);
-#else /* AFS_SGI61_ENV */
+#else
 		    fprintf(outFilep, "p%d:0x%x ", i, alp[pix]);
-#endif /* AFS_SGI61_ENV */
+#endif
 		    break;
 		case ICL_TYPE_HYPER:
 		case ICL_TYPE_INT64:
@@ -510,9 +495,6 @@ DisplayRecord(FILE *outFilep, afs_int32 *alp, afs_int32 rsize)
 
 
 #include <locale.h>
-#ifdef	AFS_OSF_ENV
-#include <limits.h>
-#endif
 #include <nl_types.h>
 
 #define FACILITY_CODE_MASK          0xF0000000
@@ -661,7 +643,6 @@ icl_DumpKernel(FILE *outFilep, char *setname)
 			    i, (long)tname, sizeof(tname), 0, 0);
 	    if (code) {
 		if (errno == EBADF) {
-		    code = 0;
 		    continue;	/* missing slot, nothing to worry about */
 		}
 		break;
@@ -760,10 +741,6 @@ icl_DumpKernel(FILE *outFilep, char *setname)
 	    /* print the record */
 	    DisplayRecord(outFilep, &bufferp[ix], rlength);
 	    ix += rlength;
-#ifdef notdef
-	    /* obsolete: read entire buffer first */
-	    i += rlength;	/* update cookie value, too */
-#endif
 	}			/* for loop displaying buffer */
     }				/* for loop over all logs */
 
@@ -1099,8 +1076,11 @@ int
 afs_syscall(long call, long parm0, long parm1, long parm2, long parm3,
 	    long parm4, long parm5, long parm6)
 {
-    int code, rval;
-#ifdef AFS_LINUX20_ENV
+    int code;
+#if defined(AFS_DARWIN80_ENV) || defined(AFS_LINUX_ENV)
+    int rval;
+#endif
+#ifdef AFS_LINUX_ENV
 #if defined AFS_LINUX_64BIT_KERNEL
     long long eparm[4];
     /* don't want to sign extend it to 64bit, so using ulong */
@@ -1118,14 +1098,24 @@ afs_syscall(long call, long parm0, long parm1, long parm2, long parm3,
     /* Linux can only handle 5 arguments in the actual syscall. */
     if (call == AFSCALL_ICL) {
 	rval = proc_afs_syscall(call, parm0, parm1, parm2, (long)eparm, &code);
-	if (rval)
+	if (rval) {
+#ifdef AFS_SYSCALL
 	    code = syscall(AFS_SYSCALL, call, parm0, parm1, parm2, eparm);
+#else
+	    code = -1;
+#endif
+	}
     } else {
 	rval = proc_afs_syscall(call, parm0, parm1, parm2, parm3, &code);
-	if (rval)
+	if (rval) {
+#ifdef AFS_SYSCALL
 	    code = syscall(AFS_SYSCALL, call, parm0, parm1, parm2, parm3);
+#else
+	    code = -1;
+#endif
+	}
     }
-#if defined(AFS_SPARC64_LINUX20_ENV) || defined(AFS_SPARC_LINUX20_ENV)
+#if defined(AFS_SPARC64_LINUX_ENV) || defined(AFS_SPARC_LINUX_ENV)
     /* on sparc this function returns none value, so do it myself */
     __asm__ __volatile__("mov	%o0, %i0; ret; restore");
 #endif
@@ -1135,7 +1125,11 @@ afs_syscall(long call, long parm0, long parm1, long parm2, long parm3,
     if (!code) code = rval;
 #else
 #if !defined(AFS_SGI_ENV) && !defined(AFS_AIX32_ENV)
+# if defined(AFS_SYSCALL)
     code = syscall(AFS_SYSCALL, call, parm0, parm1, parm2, parm3, parm4);
+# else
+    code = -1;
+# endif
 #else
 #if defined(AFS_SGI_ENV)
     code = syscall(AFS_ICL, call, parm0, parm1, parm2, parm3, parm4);	/* XXX */
@@ -1144,7 +1138,7 @@ afs_syscall(long call, long parm0, long parm1, long parm2, long parm3,
 #endif
 #endif
 #endif
-#endif /* AFS_LINUX20_ENV */
+#endif /* AFS_LINUX_ENV */
     return code;
 }
 #endif
@@ -1611,12 +1605,13 @@ icl_EnumerateLogs(int (*aproc)
 		    (char *name, void *arock, struct afs_icl_log * tp),
 		  void *arock)
 {
-    struct afs_icl_log *tp;
+    struct afs_icl_log *tp, *np;
     afs_int32 code;
 
     code = 0;
-    for (tp = afs_icl_allLogs; tp; tp = tp->nextp) {
+    for (tp = afs_icl_allLogs; tp; tp = np) {
 	tp->refCount++;		/* hold this guy */
+	np = tp->nextp;
 	code = (*aproc) (tp->name, arock, tp);
 	if (--tp->refCount == 0)
 	    icl_ZapLog(tp);
@@ -1700,7 +1695,7 @@ DoDump(struct cmd_syndesc *as, void *arock)
 	    return 1;
 	}
     }
-#ifdef AFS_SGI64_ENV
+#ifdef AFS_SGI_ENV
     startTime = time((time_t *) 0);
 #else
     startTime = time(0);
@@ -1743,7 +1738,7 @@ SetUpDump(void)
     struct cmd_syndesc *dumpSyntax;
 
     dumpSyntax =
-	cmd_CreateSyntax("dump", DoDump, NULL, "dump AFS trace logs");
+	cmd_CreateSyntax("dump", DoDump, NULL, 0, "dump AFS trace logs");
     (void)cmd_AddParm(dumpSyntax, "-set", CMD_LIST, CMD_OPTIONAL,
 		      "event set name");
     (void)cmd_AddParm(dumpSyntax, "-follow", CMD_SINGLE, CMD_OPTIONAL,
@@ -1819,7 +1814,7 @@ SetUpShowLog(void)
     struct cmd_syndesc *showSyntax;
 
     showSyntax =
-	cmd_CreateSyntax("lslog", DoShowLog, NULL,
+	cmd_CreateSyntax("lslog", DoShowLog, NULL, 0,
 			 "list available logs");
     (void)cmd_AddParm(showSyntax, "-set", CMD_LIST, CMD_OPTIONAL,
 		      "event set name");
@@ -1878,7 +1873,7 @@ SetUpShowSet(void)
     struct cmd_syndesc *showSyntax;
 
     showSyntax =
-	cmd_CreateSyntax("lsset", DoShowSet, NULL,
+	cmd_CreateSyntax("lsset", DoShowSet, NULL, 0,
 			 "list available event sets");
     (void)cmd_AddParm(showSyntax, "-set", CMD_LIST, CMD_OPTIONAL,
 		      "event set name");
@@ -1936,7 +1931,7 @@ SetUpClear(void)
     struct cmd_syndesc *clearSyntax;
 
     clearSyntax =
-	cmd_CreateSyntax("clear", DoClear, NULL,
+	cmd_CreateSyntax("clear", DoClear, NULL, 0,
 			 "clear logs by logname or by event set");
     (void)cmd_AddParm(clearSyntax, "-set", CMD_LIST, CMD_OPTIONAL,
 		      "event set name");
@@ -2023,7 +2018,7 @@ SetUpSet(void)
     struct cmd_syndesc *setSyntax;
 
     setSyntax =
-	cmd_CreateSyntax("setset", DoSet, NULL,
+	cmd_CreateSyntax("setset", DoSet, NULL, 0,
 			 "set state of event sets");
     (void)cmd_AddParm(setSyntax, "-set", CMD_LIST, CMD_OPTIONAL,
 		      "event set name");
@@ -2084,7 +2079,7 @@ SetUpResize(void)
     struct cmd_syndesc *setsizeSyntax;
 
     setsizeSyntax =
-	cmd_CreateSyntax("setlog", DoResize, NULL,
+	cmd_CreateSyntax("setlog", DoResize, NULL, 0,
 			 "set the size of a log");
     (void)cmd_AddParm(setsizeSyntax, "-log", CMD_LIST, CMD_OPTIONAL,
 		      "trace log name");
@@ -2098,7 +2093,7 @@ int
 main(int argc, char *argv[])
 {
     setlocale(LC_ALL, "");
-#ifdef AFS_SGI62_ENV
+#ifdef AFS_SGI_ENV
     set_kernel_sizeof_long();
 #endif
 
